@@ -1,15 +1,12 @@
-####################################################
-#     Delete background under profiles" function   #
-####################################################
-      
-"delete.background"<-function(mat,radius)
+delete.background <-
+function(mat,radius)
 {  
   ma<-matrix(nc=dim(mat)[2],nr=dim(mat)[1])
   for (i in 1:dim(mat)[1])
   {
     ma[i,]<-rollball(prof=mat[i,], radius)
   }
-  mat<-normalisation(mat,1)
+  
   dev.off()
   mm<-mat-ma
   layout(1:2,2,1)
@@ -26,3 +23,4 @@
 
   return(mm)
 }
+
