@@ -1,13 +1,17 @@
-################################################################
-#    GUI for the "Delete background under profiles" function   #
-################################################################
-
-"delete.backgroundGUI"<-function()                                  
+delete.backgroundGUI <-
+function()                                  
 {
 ####  Delete background on the profile
 
   checkprofile()
 
+  if (sum(mat.range)==length(mat.range))
+  {
+	  tkmessageBox(message="Attention: range function must be done before deleting background")
+	  stop()
+  }
+  matt<-mat.normalise
+   
   tt <- tktoplevel()
   tkwm.title(tt,"Delete background under fingerprint profiles")
   tkgrid(tklabel(tt,text="                                                                                                                                                   "))
@@ -20,22 +24,23 @@
   tkpack(text2,starte,side="left")
   tkgrid(tt2)
   
-  matt<-mat$profil
-  if (sum(mat1[1,])!=length(mat1[1,])) matt<-mat1
-
-  f<-function()
+  load.delete.background<-function()
   {      
     radius=as.numeric(tclvalue(it))
     ma<-delete.background(mat=matt,radius=radius)
-    mat2<<-ma
-    mat6<<-ma
-    print("Background successfully deleted")
-    tkfocus(MainMenu)
+    mat.background<<-ma
+    mat.analyse<<-ma
+	mat.binary<-matrix(nr=5,nc=2)
+	mat.binary[]<-1
+	mat.binary<<-mat.binary
+    tkmessageBox(message="Background successfully deleted")
+    dev.off()
+	tkdestroy(tt)
   }
   
   tkgrid(tklabel(tt,text=" "))
 
-  helpp<-function()
+  help.rollball<-function()
   {
     trr <- tktoplevel()
     tkwm.title(trr,"What is the radius of the rollball")
@@ -47,19 +52,16 @@
     tkgrid(tklabel(trr,text=""))
   }
   
-  tkgrid(tkbutton(tt,text="Help to define the rollball",command=helpp))
+  tkgrid(tkbutton(tt,text="Help to define the rollball",command=help.rollball))
   tkgrid(tklabel(tt,text=" ") )
   
   t1<-tkframe(tt)
-  b1<-tkbutton(t1,text="Delete background",command=f)
-  cc<-function()
-  {
-    tkdestroy(tt)
-  }
-  b2<-tkbutton(t1,text="Cancel",command=cc)
+  b1<-tkbutton(t1,text="Delete background",command=load.delete.background)
+  b2<-tkbutton(t1,text="Cancel",command=function() tkdestroy(tt))
   tkpack(b1,b2,side="left")
   tkgrid(t1)
   tkgrid(tklabel(tt,text="    "))
 
   tkfocus(tt)
 }
+
